#
# spec file for package flnews
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flnews
Version:        1.2.1
Release:        1.3
Summary:        Graphical USENET newsreader
License:        BSD-2-Clause
Group:          Productivity/Graphics/Other
URL:            http://micha.freeshell.org/flnews/
Source:         http://micha.freeshell.org/flnews/src/%{name}-%{version}.tar.bz2
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libopenssl-devel
BuildRequires:  zlib-devel
Requires:       xdg-utils

%description
flnews is a FLTK-based client with graphical user interface to read
USENET newsgroups.

%prep
%setup -q
sed -i 's|CFG_XDG_DISABLE=1|CFG_XDG_DISABLE=0|g' CONFIG
sed -i 's|CFG_NLS_PATH="$CFG_PREFIX/lib/$CFG_NAME/nls"|CFG_NLS_PATH="$CFG_PREFIX/share/$CFG_NAME/nls"|g' CONFIG

%build
export CFLAGS="%{optflags} -fPIE"
export CXXFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
make PREFIX=%{_prefix} %{?_smp_mflags}

%install
%make_install PREFIX=%{_prefix}

%files
%license LICENSE
%doc CHANGELOG README
%{_bindir}/flnews
%dir %{_datadir}/flnews/
%{_datadir}/flnews/license.txt
%dir %{_datadir}/flnews/nls
%{_datadir}/flnews/nls/de_DE.cat
%{_datadir}/flnews/nls/fr_FR.cat
%{_mandir}/man1/flnews.1%{?ext_man}
%{_datadir}/applications/flnews.desktop
%{_datadir}/icons/hicolor/*/apps/flnews.png

%changelog
* Mon May  6 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * Potential crash fixed if an article is selected while article
    tree/list widget update is still in progress (race condition).
  * FLTK 1.3 may crash if Fl_Text_Display widget contains very long
    lines. With FLTK 1.3 articles containing lines beyond 1000
    octets are no longer displayed. It's still possible to store
    the raw data to a file. With FLTK 1.4 the behaviour is unchanged.
  * Inconsistent permissions of created files fixed.
  * Conversion from multiple seldom used 8-bit codepages to Unicode
    fixed.
  * Unicode database updated to version 15.1.0.
  * Connector lines in article tree are now solid for better
    visibility.
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  * French translation added for NLS support.
  * Option to skip to next group while searching for next unread
    article added.
  * Support for custom colors in displayed article added.
  * Support for user defined TCP connection timeout.
  * Header field "Newsgroups" can now be extracted from overview,
    if present. Scoring rules of type "group" are applied to all
    groups of an Xpost in this case.
  * Support for LIST OVERVIEW.FMT command (RFC 3977) added
  * Experimental support for NNTP MAXARTNUM extension added.
  * Zero-width space (ZWSP) is now used too as line breaking hint
    for the format "flowed" decoder.
  * Soft hyphens are now handled consistently with all FLTK
    backends (formerly X11 rendered all SHY characters visible,
    as defined by ISO 8859-1, while Pango and Cocoa rendered SHY
    characters invisible).
  * Unicode database updated to version 15.0.0.
  * The experimental option USE_CUSTOM_FONTSIZE has been removed
    Since FLTK 1.4 there is a resize feature via keyboard
    (Ctrl-+/-).
  * Examples for postprocessor added in subdirectory "postproc".
  * Example for external editor added in subdirectory "editor".
* Sat May 28 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.0
  Bug fixes:
  * CORE: Authentication without password is now rejected.
  * MAIN: Potential deadlocks in thread-safe replacement functions
    fixed.
  * GUI: State machine modified to avoid race condition when
    articles are marked read while group is not completely loaded
    yet.
  New features and improvements:
  * GUI: Option to automatically check for new articles added (an
    interval in minutes can be configured with the new
    "refresh_interval" entry in configfile).
  * GUI: Checkbox "Tools->Debug mode" removed. Debug mode must be
    enabled with command line option "-debug".
  * NNTP: Protocol logfile is only created if debug mode was
    enabled (and unlinked otherwise, if present). "Tools->Protocol
    console" window now requires debug mode.
  * GUI: Support for estimated article count in subscription window
    added
  * GUI: Support for group descriptions in subscription window
    added
  * NNTP: Support for LIST NEWSGROUPS command (RFC 3977) added
  * GUI: Support for subscription proposals from server added
    (offered to user after server was changed and group list is
    empty)
  * CORE: Support for subscription proposals from server added
  * NNTP: Support for LIST SUBSCRIPTIONS command (RFC 6048) added
  * GUI: File save operations now suggest a pathname in the file
    selection window.
  * GUI: File save operations now ask the user before an existing
    file is overwritten.
  * CORE: Function added to suggest a pathname (created from home
    directory, program name and timestamp).
  * CORE: Message-IDs are now generated with algorithm A3 (uses a
    modified Base64 alphabet with "/" replaced by "-"). This
    allows to generate RFC 5538 conformant "news"-URIs without
    percent-encoding.
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.0
  Important notes:
  * The new configuration data format is not compatible with versions 0.x
    (indicated by the major number bump)!
    A script is provided to automatically convert existing configuration
    data to the new format. Read "migration/README" for details.
  * Because the location of the configuration has changed (see new XDG
    module below), the configuration for versions 0.x is preserved.
  * It is still possible to downgrade flnews to 0.x, the preserved old
    configuration data is used again in this case.
  * Now the release version contains 3 numbers "x.y.z"
    Major (x) indicates compatibility with configuration data
    Minor (y) is incremented for new features
    Patch (z) is incremented for bug fixes
  Bug fixes:
  * CORE: Request for group information is no longer rejected with error
    if the group list is empty.
  * GUI: After unsubscribing the last group, the article tree/list was not
    cleared and the user can click on articles for which the associated
    data no longer exists. Such operations will crash the program
    (reported by Martin Schnitkemper).
  * CORE: Line length limit (998 octets) is now checked before injection.
  * GUI: On macOS with system menu bar the status updates to menu entry
    "Group->Sort by article number" work now (patch from Dennis Preiser).
    The required method update() is not available with old FLTK 1.3
    libraries, the option CFG_COCOA_SYS_MENUBAR now requires FLTK 1.4.
  * ENC: URI percent encoder for scheme <news> fixed: The characters
    defined as <gen-delims> (RFC 3986 Section 2.2) are now encoded
    (reported by Marcel Logen).
  * GUI: The URI parser now accepts empty <host> for scheme <news>.
  * GUI: The current group selection is now restored after a click into
    the empty space below the group list (reported by Christian
    Schumacher).
  * GUI: The article list/tree is now cleared after selecting an empty
    group (formerly articles of an unrelated group may still be visible).
  * GUI: Some FLTK versions accept selection of deactivated items. There
    is now a workaround implemented to make such selections nonfatal.
  * GUI: Horizontal scrolling to highlighted result of search fixed.
  * GUI: Use FLTK default forground color for group subscription window
    too. This should make the content readable with dark background
    (reported by Christian Schumacher).
  * NLS: German translation "Artikel herunterladen fehlgeschlagen" fixed
    (reported by Marcel Logen).
  * GUI: If there are multiple signature separators ("-- ") present, now
    the last one is used according to "Usenet Best Practice" draft 01
    (reported by Marcel Logen).
  New features and improvements:
  * XDG: Moved default configuration directory to location defined by XDG
  * Base Directory Specification 0.7 ("$XDG_CONFIG_HOME/$CFG_NAME").
    Other modules now ask the XDG module for the configuration path.
  * MAIN: The new command line option "-confprefix" can be used to
    override the configuration directory (proposed by Helmut Waitzmann).
  * GUI: It is now possible to mark all articles in all groups as read
    (menu entry "Group->Mark all groups as read").
  * MAIN: New command line option "-debug" to enable debug mode early.
  * CONF: configfile entry "domain" replaced with "fqdn". Some users
    saw the hostname field in Message-ID algorithm A1 as privacy problem.
    A <dot-atom> can be configured for the new entry "fqdn" (should be a
    fully qualified domain name, but without root domain). It is used as
    <id-right> element when a Message-ID is created with algorithm A2.
  * Support for SOURCE_DATE_EPOCH Specification 1.1 added to build system.
    Reproducible build option CFG_REPRODUCIBLE removed from CONFIG.
    The SOURCE_DATE_EPOCH variable from the environment now overrides the
    dates in the GUI, the output of the "-v" command line option and the
    man pages (original patch from Bernhard M. Wiedemann).
  * Support for target "install-strip" added to build system. The target
    "install" no longer strips unnecessary symbols from binaries
    (proposed by Martin Schnitkemper).
  * EXT: Support for external inews added.
    Pathname can be specified with the new "inews" entry in configfile.
  * TLS: Protocol versions 1.0 and 1.1 are now disabled as required by
    RFC 8996. Both versions are still available in "weak" encryption mode.
  * GUI: New menu entry "Group->Mark subthread as read".
  * GUI: If there is only one entity to display for a MIME multipart
    message (e.g. the selected one with multipart/alternative), the
    entity header is now displayed too.
  * GUI: An initial greeting phrase can now be specified with the new
    "initial_greeting" entry in configfile. It is inserted into articles
    that start a new thread (proposed by Wolfgang Bauer).
  * FUTIL: Function added to create (multiple) missing directories of a
    path.
  * FILTER: New scorefile syntax to eliminate the workaround with type
    "extended". All score rules now have a wildmat in the first field.
  * FILTER: Simplified default regex for test group detection to
    "\.test$|^test$", removing the ".*" part at the beginning (proposed by
    Urs Janßen).
  * POSIX: Support for POSIX.1-2008 and SUSv4 added.
    No local replacement functions are used anymore on modern operating
    systems. snprintf() replacement function now uses SUSv4 semantics.
  * ENC: MIME encoded-words are now generated with "US-ASCII" charset
    declaration if there is no 8-bit data to encode in the header field
    (e.g. to represent words like " =?-?= " in a RFC 2049 conformant way).
    This follows the "lowest common denominator" principle decribed in
    RFC 2046 Section 4.1.2.
  * TLS: Deprecated functions from OpenSSL 3 API are no longer used.
  * GUI: Modified question popup windows to handle pressing ESC key as
    "No" or "Reject" respectively.
  * GUI: Some entries moved from menu "Article" to "Group".
* Fri Apr  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre42
* Sun Mar 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre34
* Sun Feb 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre29
* Mon Feb 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre27
* Sat Feb  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre23
* Thu Jan 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre19
* Fri Jan 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre16
* Tue Jan 12 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre14
* Fri Jan  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0pre13
- Drop not longer needed patch:
  * reproducible.patch
* Wed Dec 30 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Mon Nov 30 2020 Jan Engelhardt <jengelh@inai.de>
- Trim unsubstantiated marketing from descriptions.
* Mon Nov  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 0.18
* Mon Nov  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18rc4
* Mon Oct 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18rc3
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18rc2
* Wed Oct 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre61
* Mon Oct 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre59
* Mon Sep  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre55
* Tue Sep  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre53
* Mon Aug 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre52
* Tue Aug 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre51
* Fri Aug 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre50
* Thu Aug 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre48
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre47
* Tue Aug  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre44
* Mon Aug  3 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre42
* Sun Aug  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre38
* Fri Jul 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre36
* Sun Jul 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre31
* Sat Jul 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre30
* Mon Jul 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre27
* Tue Jul  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre23
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre22
* Sat Jun 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre21
* Sat Jun 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre19
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre16
* Fri Apr 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre14
* Tue Mar  3 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre12
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre11
* Sat Feb 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre10
* Sun Feb  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre9
* Thu Feb  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre8
* Wed Feb  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18pre6
* Mon Feb  3 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.18pre4
